@@ -1,9 +1,9 @@
-import ast
 from abc import ABC
 from configparser import ConfigParser
+from datetime import datetime
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import Any, Iterator, Mapping, MutableMapping
+from typing import Any, Collection, Iterator, Mapping, MutableMapping, Union
 
 import tomli
 import tomli_w
@@ -58,7 +58,7 @@ class ConfigurationTable(MutableMapping, ABC):
                 for section_name, section in SETUP_CFG.items():
                     if section != "DEFAULT":
                         for key, value in setup_py.items():
-                            if key in section:
+                            if key.strip() in section:
                                 if not isinstance(value, Mapping):
                                     value = inify(value=value)
                                     if section_name not in setup_cfg.sections():
@@ -106,48 +106,39 @@ class ConfigurationTable(MutableMapping, ABC):
             )
             file_configuration = tomli.loads(toml_string)
             if "project" in file_configuration:
-                if "homepage" in file_configuration["project"]:
-                    if "urls" not in file_configuration["project"]:
-                        file_configuration["project"]["urls"] = ConfigurationSubTable()
-                    file_configuration["project"]["urls"][
-                        "homepage"
-                    ] = file_configuration["project"]["homepage"]
-                    del file_configuration["project"]["homepage"]
-            if (
-                "tool" in file_configuration
-                and "setuptools" in file_configuration["tool"]
-            ):
-                if "packages" in file_configuration["tool"]["setuptools"]:
-                    if "find" in file_configuration["tool"]["setuptools"]["packages"]:
-                        if (
-                            "namespaces"
-                            in file_configuration["tool"]["setuptools"]["packages"][
-                                "find"
-                            ]
-                        ):
-                            file_configuration["tool"]["setuptools"]["packages"][
-                                "find"
-                            ]["namespaces"] = ast.literal_eval(
-                                file_configuration["tool"]["setuptools"]["packages"][
-                                    "find"
-                                ]["namespaces"]
-                            )
-                if setup_py is not None:
-                    if "extras-require" in file_configuration["tool"]["setuptools"]:
-                        if "project" not in file_configuration:
-                            file_configuration["project"] = ConfigurationSubTable()
-                        file_configuration["project"][
-                            "optional-dependencies"
-                        ] = setup_py["extras_require"]
-                        del file_configuration["tool"]["setuptools"]["extras-require"]
-                    if "package-data" in file_configuration["tool"]["setuptools"]:
-                        if "project" not in file_configuration:
-                            file_configuration["tool"][
-                                "setuptools"
-                            ] = ConfigurationSubTable()
-                        file_configuration["tool"]["setuptools"][
-                            "package-data"
-                        ] = setup_py["package_data"]
+                project_table = file_configuration["project"]
+                if "homepage" in project_table:
+                    if "urls" not in project_table:
+                        project_table["urls"] = ConfigurationSubTable()
+                    project_table["urls"]["homepage"] = project_table["homepage"]
+                    del project_table["homepage"]
+                file_configuration["project"] = project_table
+            if "tool" in file_configuration:
+                tool_table = file_configuration["tool"]
+                if "setuptools" in tool_table:
+                    setuptools_table = tool_table["setuptools"]
+                    if "packages" in setuptools_table:
+                        packages_table = setuptools_table["packages"]
+                        if "find" in packages_table:
+                            if "namespaces" in packages_table["find"]:
+                                packages_table["find"]["namespaces"] = (
+                                    packages_table["find"]["namespaces"] == "True"
+                                )
+                        setuptools_table["packages"] = packages_table
+                    if setup_py is not None:
+                        if "extras-require" in setuptools_table:
+                            if "project" not in file_configuration:
+                                file_configuration["project"] = ConfigurationSubTable()
+                            file_configuration["project"][
+                                "optional-dependencies"
+                            ] = setup_py["extras_require"]
+                            del setuptools_table["extras-require"]
+                        if "package-data" in setuptools_table:
+                            if "project" not in file_configuration:
+                                setuptools_table = ConfigurationSubTable()
+                            setuptools_table["package-data"] = setup_py["package_data"]
+                    tool_table["setuptools"] = setuptools_table
+                file_configuration["tool"] = tool_table
             base_table = cls.name.split(".", 1)[0]
             if base_table in file_configuration:
                 configuration.update(file_configuration[base_table])
@@ -263,9 +254,24 @@ class ConfigurationTable(MutableMapping, ABC):
             ],
         )
 
+    @property
+    def __toml(self) -> dict[str, Union[str, dict]]:
+        return {
+            key: value.__toml
+            if isinstance(value, ConfigurationTable)
+            else str(value)
+            if not isinstance(
+                value,
+                (str, int, float, bool, datetime, Collection, Mapping),
+            )
+            else value
+            for key, value in self.__configuration.items()
+            if value is not None
+        }
+
     @property
     def configuration(self) -> str:
-        return table_to_toml(table_name=self.name, table=self.__configuration)
+        return tomli_w.dumps(to_dict({self.name: self.__toml}))
 
     def to_file(self, filename: str):
         with open(filename, "w") as configuration_file:
@@ -303,10 +309,3 @@ def to_dict(value: Mapping) -> dict:
     else:
         output = value
     return output
-
-
-def table_to_toml(table_name: str, table: MutableMapping[str, Any]) -> str:
-    table = {
-        table_name: {key: value for key, value in table.items() if value is not None},
-    }
-    return tomli_w.dumps(to_dict(table))
