@@ -111,6 +111,8 @@ def parse_function_parameters(
             parameter_index += 1
     for parameter in parameters:
         name, value = parameter.strip().split("=", 1)
+        name = name.strip()
+        value = value.strip()
         if "open(" in value:
             value = re.findall(r"open\((.+?)\).read\(\)", value)[0]
 
@@ -121,8 +123,11 @@ def parse_function_parameters(
         value = re.sub(r"\]\s*\+\s*\[", ",", value)
         value = re.sub(r"\}\s*\+\s*\*\*\{", ",", value)
 
-        with contextlib.suppress(Exception):
+        try:
             value = ast.literal_eval(value)
+        except:
+            if name == "version":
+                continue
 
         if isinstance(value, str) and "find_packages(" in value:
             value = {
@@ -174,7 +179,8 @@ def read_python_file(filename: str) -> list[str]:
     statements = [statement for statement in statements if len(statement) > 0]
 
     indices = []
-    for index, statement in reversed(list(enumerate(statements))):
+    for index in reversed(range(len(statements))):
+        statement = statements[index]
         if any(
             statement.strip().endswith(continuing_character)
             for continuing_character in PYTHON_LINE["continuing"]
@@ -183,10 +189,10 @@ def read_python_file(filename: str) -> list[str]:
                 statements[index] += statements[index + 1]
                 indices.append(index + 1)
         elif any(
-            statement.strip() == ending_character
+            statement.strip().startswith(ending_character)
             for ending_character in PYTHON_LINE["ending"]
         ):
-            statements[index - 1] += statements[index]
+            statements[index - 1] += statement
             indices.append(index)
 
     for index in indices:
