@@ -2,13 +2,15 @@ import warnings
 from pathlib import Path
 from typing import Any, Mapping, Union
 
+import tomli_w
 import typepigeon
 
-from peppyproject.base import ConfigurationTable, table_to_toml
+from peppyproject.base import ConfigurationTable, to_dict
 from peppyproject.tools import CoverageTable, SetuptoolsTable
 from peppyproject.tools.base import ToolTable
 from peppyproject.tools.flake8 import Flake8Table
 from peppyproject.tools.ruff import RuffTable
+from peppyproject.tools.setuptools_scm import SetuptoolsSCMTable
 
 
 class ProjectMetadata(ConfigurationTable):
@@ -38,7 +40,6 @@ class ProjectMetadata(ConfigurationTable):
     }
 
     def __setitem__(self, key: str, value: Any):
-        generic = self.fields[key]
         directory = Path(
             self._ConfigurationTable__from_directory
             if hasattr(self, "_ConfigurationTable__from_directory")
@@ -107,32 +108,34 @@ class ProjectMetadata(ConfigurationTable):
                             value = readme_files[0]
                         else:
                             value = {"text": value, "content-type": "text/plain"}
-            elif key == "optional-dependencies":
-                if not isinstance(value, generic.__origin__):
-                    value = typepigeon.to_type(value, generic)
-                for extra in value:
-                    value[extra] = [
-                        extra_dependency
-                        for extra_dependency in typepigeon.to_type(
-                            value[extra],
-                            generic.__args__[1],
-                        )
-                        if len(extra_dependency) > 0
-                    ]
-            elif key == "entry-points":
-                if not isinstance(value, generic.__origin__):
-                    value = typepigeon.to_type(value, generic)
-                for entry_point_location in value:
-                    entry_points = value[entry_point_location]
-                    if isinstance(entry_points, str) and "=" in entry_points:
-                        entry_points = [
-                            tuple(entry.strip() for entry in entry_point.split("="))
-                            for entry_point in entry_points.splitlines()
-                            if len(entry_point) > 0
+            elif key in self.fields:
+                generic = self.fields[key]
+                if key == "optional-dependencies":
+                    if not isinstance(value, generic.__origin__):
+                        value = typepigeon.to_type(value, generic)
+                    for extra in value:
+                        value[extra] = [
+                            extra_dependency
+                            for extra_dependency in typepigeon.to_type(
+                                value[extra],
+                                generic.__args__[1],
+                            )
+                            if len(extra_dependency) > 0
                         ]
-                        value[entry_point_location] = {
-                            key: value for key, value in entry_points
-                        }
+                elif key == "entry-points":
+                    if not isinstance(value, generic.__origin__):
+                        value = typepigeon.to_type(value, generic)
+                    for entry_point_location in value:
+                        entry_points = value[entry_point_location]
+                        if isinstance(entry_points, str) and "=" in entry_points:
+                            entry_points = [
+                                tuple(entry.strip() for entry in entry_point.split("="))
+                                for entry_point in entry_points.splitlines()
+                                if len(entry_point) > 0
+                            ]
+                            value[entry_point_location] = {
+                                key: value for key, value in entry_points
+                            }
 
         super().__setitem__(key, value)
 
@@ -149,6 +152,21 @@ class BuildConfiguration(ConfigurationTable):
         "build-backend": str,
     }
 
+    @classmethod
+    def default_setuptools(cls):
+        configuration = cls()
+
+        if configuration["build-backend"] is None:
+            configuration["build-backend"] = "setuptools.build_meta"
+        if configuration["requires"] is None or len(configuration["requires"]) == 0:
+            configuration["requires"] = ["setuptools>=61.2", "wheel"]
+        elif not any(
+            "setuptools" in requirement for requirement in configuration["requires"]
+        ):
+            configuration["requires"].append("setuptools>=61.2")
+
+        return configuration
+
 
 class ToolsTable(ConfigurationTable):
     """
@@ -158,6 +176,7 @@ class ToolsTable(ConfigurationTable):
     name = "tool"
     fields = {
         "setuptools": SetuptoolsTable,
+        "setuptools_scm": SetuptoolsSCMTable,
         "coverage": CoverageTable,
         "flake8": Flake8Table,
         "ruff": RuffTable,
@@ -192,10 +211,10 @@ class ToolsTable(ConfigurationTable):
 
     @property
     def configuration(self) -> str:
-        tables = self._ConfigurationTable__configuration
+        tables = self._ConfigurationTable__toml
         for table_name, table in tables.items():
             if isinstance(table, ConfigurationTable):
                 tables[table_name] = {
                     key: value for key, value in table.items() if value is not None
                 }
-        return table_to_toml(table_name="tool", table=tables)
+        return tomli_w.dumps(to_dict({"tool": tables}))
